<?php

namespace app\models\base;

use Yii;

/**
 * This is the model class for table "news".
 *
 * @property int $id Уникальный id
 * @property string $uid uid
 * @property string $alias символный URL
 * @property string $old_url
 * @property string $dt_pub дата публикации
 * @property string $dt_cr дата создания
 * @property string $dt_upd дата изменения
 * @property int $rev ревизия документа
 * @property string $title заг h1
 * @property string $lid лид
 * @property string $text содержание
 * @property string|null $meta_title meta title
 * @property string $author автор
 * @property string $show_author Показывать автора
 * @property string $editors редакторы
 * @property string $link URL редиректа
 * @property string $embed_url медиа вставка
 * @property string $photo_name имя фото файла
 * @property string $photo_title подпись фото
 * @property string $photo_include Показывать миниатюру
 * @property string $photo_rcol Показывать в доп колонке
 * @property string $active 0 не пуб. 1 - норм 2 - топ
 * @property string $verifed Проверено корректором
 * @property string $top в топ новости
 * @property string $NH Новость часа
 * @property string $comments Включать коменты
 * @property int $flags флаги бит маска
 * @property string $photo фотогалерея
 * @property string $video видео
 * @property string $audio аудио
 * @property int $export_rss не отдавать в Яндекс новости (mail,dzen,..) бит маска
 * @property string $noindex Не отдавать в поиск
 * @property int $type тип публикации
 * @property int $inscription подпись после статьи (на правах рекл. мед.)
 * @property string $old_gallery_title подпись к старым галереям
 * @property NewsTopic[] $topics
 */
class News extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'news';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'uid', 'old_url', 'rev', 'title', 'lid', 'text', 'editors', 'embed_url', 'photo_name', 'photo_title', 'type', 'old_gallery_title'], 'required'],
            [['id', 'rev', 'flags', 'export_rss', 'type', 'inscription'], 'integer'],
            [['dt_pub', 'dt_cr', 'dt_upd'], 'safe'],
            [['title', 'lid', 'text', 'show_author', 'editors', 'embed_url', 'photo_name', 'photo_title', 'photo_include', 'photo_rcol', 'active', 'verifed', 'top', 'NH', 'comments', 'photo', 'video', 'audio', 'noindex', 'old_gallery_title'], 'string'],
            [['uid'], 'string', 'max' => 36],
            [['alias', 'old_url', 'author', 'link'], 'string', 'max' => 255],
            [['meta_title'], 'string', 'max' => 70],
            [['id'], 'unique'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'uid' => 'Uid',
            'alias' => 'Alias',
            'old_url' => 'Old Url',
            'dt_pub' => 'Dt Pub',
            'dt_cr' => 'Dt Cr',
            'dt_upd' => 'Dt Upd',
            'rev' => 'Rev',
            'title' => 'Title',
            'lid' => 'Lid',
            'text' => 'Text',
            'meta_title' => 'Meta Title',
            'author' => 'Author',
            'show_author' => 'Show Author',
            'editors' => 'Editors',
            'link' => 'Link',
            'embed_url' => 'Embed Url',
            'photo_name' => 'Photo Name',
            'photo_title' => 'Photo Title',
            'photo_include' => 'Photo Include',
            'photo_rcol' => 'Photo Rcol',
            'active' => 'Active',
            'verifed' => 'Verifed',
            'top' => 'Top',
            'NH' => 'Nh',
            'comments' => 'Comments',
            'flags' => 'Flags',
            'photo' => 'Photo',
            'video' => 'Video',
            'audio' => 'Audio',
            'export_rss' => 'Export Rss',
            'noindex' => 'Noindex',
            'type' => 'Type',
            'inscription' => 'Inscription',
            'old_gallery_title' => 'Old Gallery Title',
        ];
    }

    /**
     * {@inheritdoc}
     * @return NewsQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new NewsQuery(get_called_class());
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getTopicRelations()
    {
        return $this->hasMany(NewsTopicRelation::class,['news_id'=>'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getTopics()
    {
        return $this->hasMany(NewsTopic::class,['id'=>'topic_id'])->via('topicRelations');
    }
}
